##  Examples
To explore JavaScript code samples for common use cases, see [Calculation Examples](https://help.sap.com/docs/leanix/ea/calculation-examples?locale=en-US&state=PRODUCTION&version=CLOUD "JavaScript code samples for common use cases.").
